%define package_trust_dir %{_datadir}/pki/trust
%define p11_format_bundle mozilla.p11-kit

Name: ca-certificates-mozilla
Summary: The Mozilla CA root certificate bundle

# For the package version number, we use: year.{upstream version}
#
# The {upstream version} can be found as symbol
# NSS_BUILTINS_LIBRARY_VERSION in file nss/lib/ckfw/builtins/nssckbi.h
# which corresponds to the data in file nss/lib/ckfw/builtins/certdata.txt.
#
# The files should be taken from a released version of NSS, as published
# at https://ftp.mozilla.org/pub/mozilla.org/security/nss/releases/
#
# The versions that are used by the latest released version of 
# Mozilla Firefox should be available from:
# https://hg.mozilla.org/releases/mozilla-release/raw-file/default/security/nss/lib/ckfw/builtins/nssckbi.h
# https://hg.mozilla.org/releases/mozilla-release/raw-file/default/security/nss/lib/ckfw/builtins/certdata.txt
#
# The most recent development versions of the files can be found at
# http://hg.mozilla.org/projects/nss/raw-file/default/lib/ckfw/builtins/nssckbi.h
# http://hg.mozilla.org/projects/nss/raw-file/default/lib/ckfw/builtins/certdata.txt
# (but these files might have not yet been released).

# https://hg.mozilla.org/projects/nss/raw-file/NSS_3_32_BRANCH/lib/ckfw/builtins/nssckbi.h

Version: 2022.2.58
Release: 1
License: MPL-2.0

#Please always update both certdata.txt and nssckbi.h
Source0: certdata.txt
Source1: nssckbi.h

Source2: certdata2pem.py

BuildArch: noarch

Requires(post): %{_bindir}/update-ca-certificates

BuildRequires: python2
BuildRequires: openssl

# Obsolete the ca-certificates package that Yvan created
Obsoletes: ca-certificates < 2
Conflicts: ca-certificates < 2

%description
This package contains the set of CA certificates chosen by the
Mozilla Foundation for use with the Internet PKI.

%prep
%setup -q -c -T


%build
mkdir certs
cd certs
    cp %{SOURCE0} .
    python2 %{SOURCE2} > c2p.log 2> c2p.err
cd ..

(
   cat <<EOF
# This is a bundle of X.509 certificates of public Certificate
# Authorities.  It was generated from the Mozilla root CA list.
# These certificates and trust/distrust attributes use the file format accepted
# by the p11-kit-trust module.
#
# Source: nss/lib/ckfw/builtins/certdata.txt
# Source: nss/lib/ckfw/builtins/nssckbi.h
#
# Generated from:
EOF
   grep -w NSS_BUILTINS_LIBRARY_VERSION %{SOURCE1} | awk '{print "# " $2 " " $3}'
   echo '#'
) > %{p11_format_bundle}

cat certs/*.tmp-p11-kit >> %{p11_format_bundle} || :


%install

mkdir -p %{buildroot}%{package_trust_dir}

install -p -m 644 %{p11_format_bundle} %{buildroot}%{package_trust_dir}/%{p11_format_bundle}


%post
%{_bindir}/update-ca-certificates


%files
%defattr(-, qsys, *none)

%{package_trust_dir}/%{p11_format_bundle}


%changelog
* Tue Sep 20 2022 Xu Meng <mengxumx@cn.ibm.com> - 2022.2.58
- Update to version 2022.2.58

* Wed Jan 13 2021 Abdirahim Musse <abdirahim.musse@ibm.com> - 2021.2.46
- Update to version 2021.2.46

* Fri Mar 22 2019 Kevin Adler <kadler@us.ibm.com>
- Initial release based off of Fedora 28 package
- Update to latest Mozilla version
